@@ -15,7 +15,7 @@ from ..types import (
 )
 from ._types import (
     LogCallback,
-    RequestOptions,
+    BaseRequestOptions,
     LongRequestOptions,
     PollingRequestOptions,
     SDKDevboxExecuteParams,
@@ -32,13 +32,12 @@ from ._types import (
 )
 from .._client import AsyncRunloop
 from ._helpers import filter_params
-from .protocols import AsyncFileInterface, AsyncCommandInterface, AsyncNetworkInterface
 from .._streaming import AsyncStream
 from ..lib.polling import PollingConfig
+from ..types.devboxes import ExecutionUpdateChunk
 from .async_execution import AsyncExecution, _AsyncStreamingGroup
 from .async_execution_result import AsyncExecutionResult
-from ..types.devbox_execute_async_params import DevboxExecuteAsyncParams
-from ..types.devboxes.execution_update_chunk import ExecutionUpdateChunk
+from ..types.devbox_execute_async_params import DevboxNiceExecuteAsyncParams
 from ..types.devbox_async_execution_detail_view import DevboxAsyncExecutionDetailView
 
 StreamFactory = Callable[[], Awaitable[AsyncStream[ExecutionUpdateChunk]]]
@@ -55,9 +54,9 @@ class AsyncDevbox:
     management.
 
     Example:
-        >>> devbox = await sdk.devbox.create(name="my-devbox")
+        >>> devbox = await runloop.devbox.create(name="my-devbox")
         >>> async with devbox:
-        ...     result = await devbox.cmd.exec(command="echo 'hello'")
+        ...     result = await devbox.cmd.exec("echo 'hello'")
         ...     print(await result.stdout())
         # Devbox is automatically shut down on exit
     """
@@ -104,7 +103,7 @@ class AsyncDevbox:
 
     async def get_info(
         self,
-        **options: Unpack[RequestOptions],
+        **options: Unpack[BaseRequestOptions],
     ) -> DevboxView:
         """Retrieve current devbox status and metadata.
 
@@ -173,18 +172,36 @@ class AsyncDevbox:
 
     async def resume(
         self,
+        *,
+        polling_config: PollingConfig | None = None,
         **options: Unpack[LongRequestOptions],
     ) -> DevboxView:
-        """Resume a suspended devbox.
+        """Resume a suspended devbox, restoring it to running state.
 
-        Returns immediately after issuing the resume request. Call
-        :meth:`await_running` if you need to wait for the devbox to reach the
-        ``running`` state (contrast with the synchronous SDK, which blocks).
+        Waits for the devbox to reach running state before returning.
 
+        :param polling_config: Optional polling behavior overrides, defaults to None
+        :type polling_config: PollingConfig | None, optional
         :param options: Optional long-running request configuration
         :return: Resumed devbox state info
         :rtype: DevboxView
         """
+        await self.resume_async(**options)
+        return await self.await_running(polling_config=polling_config)
+
+    async def resume_async(
+        self,
+        **options: Unpack[LongRequestOptions],
+    ) -> DevboxView:
+        """Resume a suspended devbox without waiting for it to reach running state.
+
+        Initiates the resume operation and returns immediately. Use :meth:`await_running`
+        to wait for the devbox to reach running state if needed.
+
+        :param options: Optional long-running request configuration
+        :return: Devbox state info immediately after resume request
+        :rtype: DevboxView
+        """
         return await self._client.devboxes.resume(
             self._id,
             **options,
@@ -259,7 +276,7 @@ class AsyncDevbox:
         :return: Helper for running shell commands
         :rtype: AsyncCommandInterface
         """
-        return _AsyncCommandInterface(self)
+        return AsyncCommandInterface(self)
 
     @property
     def file(self) -> AsyncFileInterface:
@@ -268,7 +285,7 @@ class AsyncDevbox:
         :return: Helper for reading/writing files
         :rtype: AsyncFileInterface
         """
-        return _AsyncFileInterface(self)
+        return AsyncFileInterface(self)
 
     @property
     def net(self) -> AsyncNetworkInterface:
@@ -277,7 +294,40 @@ class AsyncDevbox:
         :return: Helper for SSH keys and tunnels
         :rtype: AsyncNetworkInterface
         """
-        return _AsyncNetworkInterface(self)
+        return AsyncNetworkInterface(self)
+
+    def shell(self, shell_name: str | None = None) -> AsyncNamedShell:
+        """Create a named shell instance for stateful command execution.
+
+        Named shells are stateful and maintain environment variables and the current working
+        directory (CWD) across commands, just like a real shell on your local computer.
+        Commands executed through the same named shell instance will execute sequentially -
+        the shell can only run one command at a time with automatic queuing. This ensures
+        that environment changes and directory changes from one command are preserved for
+        the next command.
+
+        :param shell_name: The name of the persistent shell session. If not provided, a UUID will be generated automatically.
+        :type shell_name: str | None, optional
+        :return: An AsyncNamedShell instance for executing commands in the named shell
+        :rtype: AsyncNamedShell
+
+        Example:
+            >>> # Create a named shell with a custom name
+            >>> shell = await devbox.shell("my-session")
+            >>> # Create a named shell with an auto-generated UUID name
+            >>> shell2 = await devbox.shell()
+            >>> # Commands execute sequentially and share state
+            >>> await shell.exec("cd /app")
+            >>> await shell.exec("export MY_VAR=value")
+            >>> result = await shell.exec("echo $MY_VAR")  # Will output 'value'
+            >>> result = await shell.exec("pwd")  # Will output '/app'
+        """
+        if shell_name is None:
+            # uuid_utils is not typed
+            from uuid_utils import uuid7  # type: ignore
+
+            shell_name = str(uuid7())
+        return AsyncNamedShell(self, shell_name)
 
     # ------------------------------------------------------------------ #
     # Internal helpers
@@ -357,7 +407,7 @@ class AsyncDevbox:
             logger.exception("error streaming %s logs for devbox %s", name, self._id)
 
 
-class _AsyncCommandInterface:
+class AsyncCommandInterface:
     """Interface for executing commands on a devbox.
 
     Accessed via devbox.cmd property. Provides exec() for synchronous execution
@@ -369,6 +419,7 @@ class _AsyncCommandInterface:
 
     async def exec(
         self,
+        command: str,
         **params: Unpack[SDKDevboxExecuteParams],
     ) -> AsyncExecutionResult:
         """Execute a command synchronously and wait for completion.
@@ -378,7 +429,7 @@ class _AsyncCommandInterface:
         :rtype: AsyncExecutionResult
 
         Example:
-            >>> result = await devbox.cmd.exec(command="echo 'hello'")
+            >>> result = await devbox.cmd.exec("echo 'hello'")
             >>> print(await result.stdout())
             >>> print(f"Exit code: {result.exit_code}")
         """
@@ -387,7 +438,8 @@ class _AsyncCommandInterface:
 
         execution: DevboxAsyncExecutionDetailView = await client.devboxes.execute_async(
             devbox.id,
-            **filter_params(params, DevboxExecuteAsyncParams),
+            command=command,
+            **filter_params(params, DevboxNiceExecuteAsyncParams),
             **filter_params(params, LongRequestOptions),
         )
         streaming_group = devbox._start_streaming(
@@ -422,6 +474,7 @@ class _AsyncCommandInterface:
 
     async def exec_async(
         self,
+        command: str,
         **params: Unpack[SDKDevboxExecuteAsyncParams],
     ) -> AsyncExecution:
         """Execute a command asynchronously without waiting for completion.
@@ -435,7 +488,7 @@ class _AsyncCommandInterface:
         :rtype: AsyncExecution
 
         Example:
-            >>> execution = await devbox.cmd.exec_async(command="sleep 10")
+            >>> execution = await devbox.cmd.exec_async("sleep 10")
             >>> state = await execution.get_state()
             >>> print(f"Status: {state.status}")
             >>> await execution.kill()  # Terminate early if needed
@@ -445,7 +498,8 @@ class _AsyncCommandInterface:
 
         execution: DevboxAsyncExecutionDetailView = await client.devboxes.execute_async(
             devbox.id,
-            **filter_params(params, DevboxExecuteAsyncParams),
+            command=command,
+            **filter_params(params, DevboxNiceExecuteAsyncParams),
             **filter_params(params, LongRequestOptions),
         )
 
@@ -457,7 +511,7 @@ class _AsyncCommandInterface:
         return AsyncExecution(client, devbox.id, execution, streaming_group)
 
 
-class _AsyncFileInterface:
+class AsyncFileInterface:
     """Interface for file operations on a devbox.
 
     Accessed via devbox.file property. Provides coroutines for reading, writing,
@@ -547,7 +601,104 @@ class _AsyncFileInterface:
         )
 
 
-class _AsyncNetworkInterface:
+class AsyncNamedShell:
+    """Interface for executing commands in a persistent, stateful shell session.
+
+    Named shells are stateful and maintain environment variables and the current working
+    directory (CWD) across commands. Commands executed through the same named shell
+    instance will execute sequentially - the shell can only run one command at a time
+    with automatic queuing. This ensures that environment changes and directory changes
+    from one command are preserved for the next command.
+
+    Use :meth:`AsyncDevbox.shell` to create a named shell instance. If you use the same
+    shell name, it will re-attach to the existing named shell, preserving its state.
+
+    Example:
+        >>> shell = await devbox.shell("my-session")
+        >>> await shell.exec("cd /app")
+        >>> await shell.exec("export MY_VAR=value")
+        >>> result = await shell.exec("echo $MY_VAR")  # Will output 'value'
+        >>> result = await shell.exec("pwd")  # Will output '/app'
+    """
+
+    def __init__(self, devbox: AsyncDevbox, shell_name: str) -> None:
+        """Initialize the named shell.
+
+        :param devbox: The async devbox instance to execute commands on
+        :type devbox: AsyncDevbox
+        :param shell_name: The name of the persistent shell session
+        :type shell_name: str
+        """
+        self._devbox = devbox
+        self._shell_name = shell_name
+
+    async def exec(
+        self,
+        command: str,
+        **params: Unpack[SDKDevboxExecuteParams],
+    ) -> AsyncExecutionResult:
+        """Execute a command in the named shell and wait for it to complete.
+
+        The command will execute in the persistent shell session, maintaining environment
+        variables and the current working directory from previous commands. Commands are
+        queued and execute sequentially - only one command runs at a time in the named shell.
+
+        Optionally provide callbacks to stream logs in real-time. When callbacks are provided,
+        this method waits for both the command to complete AND all streaming data to be
+        processed before returning.
+
+        :param command: The command to execute
+        :type command: str
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKDevboxExecuteParams` for available parameters
+        :return: Wrapper with exit status and output helpers
+        :rtype: AsyncExecutionResult
+
+        Example:
+            >>> shell = await devbox.shell("my-session")
+            >>> result = await shell.exec("ls -la")
+            >>> print(await result.stdout())
+            >>> # With streaming callbacks
+            >>> result = await shell.exec("npm install", stdout=lambda line: print(f"[LOG] {line}"))
+        """
+        # Ensure shell_name is set and cannot be overridden by user params
+        params["shell_name"] = self._shell_name
+        return await self._devbox.cmd.exec(command, **params)
+
+    async def exec_async(
+        self,
+        command: str,
+        **params: Unpack[SDKDevboxExecuteAsyncParams],
+    ) -> AsyncExecution:
+        """Execute a command in the named shell asynchronously without waiting for completion.
+
+        The command will execute in the persistent shell session, maintaining environment
+        variables and the current working directory from previous commands. Commands are
+        queued and execute sequentially - only one command runs at a time in the named shell.
+
+        Optionally provide callbacks to stream logs in real-time as they are produced.
+        Callbacks fire in real-time as logs arrive. When you call execution.result(),
+        it will wait for both the command to complete and all streaming to finish.
+
+        :param command: The command to execute
+        :type command: str
+        :param params: See :typeddict:`~runloop_api_client.sdk._types.SDKDevboxExecuteAsyncParams` for available parameters
+        :return: Handle for managing the running process
+        :rtype: AsyncExecution
+
+        Example:
+            >>> shell = await devbox.shell("my-session")
+            >>> execution = await shell.exec_async("long-running-task.sh", stdout=lambda line: print(f"[LOG] {line}"))
+            >>> # Do other work while command runs...
+            >>> result = await execution.result()
+            >>> if result.success:
+            ...     print("Task completed successfully!")
+        """
+        # Ensure shell_name is set and cannot be overridden by user params
+        params["shell_name"] = self._shell_name
+        return await self._devbox.cmd.exec_async(command, **params)
+
+
+class AsyncNetworkInterface:
     """Interface for networking operations on a devbox.
 
     Accessed via devbox.net property. Provides coroutines for SSH access and tunneling.
