@@ -5,7 +5,7 @@ from __future__ import annotations
 from typing_extensions import Unpack, override
 
 from ._types import (
-    RequestOptions,
+    BaseRequestOptions,
     LongRequestOptions,
     PollingRequestOptions,
     SDKDiskSnapshotUpdateParams,
@@ -13,8 +13,8 @@ from ._types import (
 )
 from .devbox import Devbox
 from .._client import Runloop
+from ..types.devboxes import DevboxSnapshotAsyncStatusView
 from ..types.devbox_snapshot_view import DevboxSnapshotView
-from ..types.devboxes.devbox_snapshot_async_status_view import DevboxSnapshotAsyncStatusView
 
 
 class Snapshot:
@@ -50,7 +50,7 @@ class Snapshot:
 
     def get_info(
         self,
-        **options: Unpack[RequestOptions],
+        **options: Unpack[BaseRequestOptions],
     ) -> DevboxSnapshotAsyncStatusView:
         """Retrieve the latest snapshot status.
 
