@@ -5,9 +5,10 @@ from __future__ import annotations
 from typing import Iterable
 from typing_extensions import Unpack, override
 
-from ._types import RequestOptions, LongRequestOptions, SDKObjectDownloadParams
+from ._types import BaseRequestOptions, LongRequestOptions, SDKObjectDownloadParams
 from .._client import Runloop
 from ..types.object_view import ObjectView
+from ..types.blueprint_create_params import BuildContext
 from ..types.object_download_url_view import ObjectDownloadURLView
 
 
@@ -52,7 +53,7 @@ class StorageObject:
 
     def refresh(
         self,
-        **options: Unpack[RequestOptions],
+        **options: Unpack[BaseRequestOptions],
     ) -> ObjectView:
         """Fetch the latest metadata for the object.
 
@@ -150,8 +151,10 @@ class StorageObject:
     def upload_content(self, content: str | bytes | Iterable[bytes]) -> None:
         """Upload content to the object's pre-signed URL.
 
-        :param content: Bytes or text payload to upload
-        :type content: str | bytes
+        :param content: Bytes payload, text payload, or an iterable streaming bytes
+        :type content: str | bytes | Iterable[bytes]
+        :return: None
+        :rtype: None
         :raises RuntimeError: If no upload URL is available
         :raises httpx.HTTPStatusError: Propagated from the underlying ``httpx`` client when the upload fails
         """
@@ -159,6 +162,20 @@ class StorageObject:
         response = self._client._client.put(url, content=content)
         response.raise_for_status()
 
+    def as_build_context(self) -> BuildContext:
+        """Return this object in the shape expected for a Blueprint build context.
+
+        The returned mapping can be passed directly to ``build_context``
+        when creating a blueprint.
+
+        :return: Mapping suitable for use as a blueprint build context
+        :rtype: BuildContext
+        """
+        return {
+            "object_id": self._id,
+            "type": "object",
+        }
+
     def _ensure_upload_url(self) -> str:
         """Return the upload URL, ensuring it is present.
 
